@@ -20,6 +20,11 @@ from .salesforce import SalesForceReport, Soql
 from .shaper import Shaper
 from .timer import Timer
 import easier.hvtools as hv  # Need this weird import to make hv symbol work 
+import easier.filtering as filtering
+# from .filtering import (
+#     Eliptic,
+#     tvd
+# )
 
 from .outlier_tools import (
     kill_outliers_iqr,
